my_responsive_ui library

Classes

ResponsiveInitializer
A widget that initializes responsive scaling and updates it based on screen size.
ResponsiveUtil
A utility class for responsive design.

Extensions

ExtSize on num
Extension on num to provide responsive size utilities.

Functions

horizontalSp(double width) Widget
A widget that provides horizontal spacing with responsive width scaling.
hs(double width) Widget
Alias for horizontalSp to simplify horizontal spacing usage.
isAndroid(BuildContext context) bool
Returns true if the platform is Android.
isIOS(BuildContext context) bool
Returns true if the platform is iOS.
isLandscape(BuildContext context) bool
Returns true if the device is in landscape mode.
isPortrait(BuildContext context) bool
Returns true if the device is in portrait mode.
verticalSp(double height) Widget
A widget that provides vertical spacing with responsive height scaling.
vs(double height) Widget
Alias for verticalSp to simplify vertical spacing usage.