my_responsive_ui library
Classes
- ResponsiveInitializer
- A widget that initializes responsive scaling and updates it based on screen size.
- ResponsiveUtil
- A utility class for responsive design.
Functions
-
horizontalSp(
double width) → Widget - A widget that provides horizontal spacing with responsive width scaling.
-
hs(
double width) → Widget - Alias for horizontalSp to simplify horizontal spacing usage.
-
isAndroid(
BuildContext context) → bool -
Returns
trueif the platform is Android. -
isIOS(
BuildContext context) → bool -
Returns
trueif the platform is iOS. -
isLandscape(
BuildContext context) → bool -
Returns
trueif the device is in landscape mode. -
isPortrait(
BuildContext context) → bool -
Returns
trueif the device is in portrait mode. -
verticalSp(
double height) → Widget - A widget that provides vertical spacing with responsive height scaling.
-
vs(
double height) → Widget - Alias for verticalSp to simplify vertical spacing usage.